package com.fusi24.rfid.ui.scanresult;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.os.Bundle;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.recyclerview.widget.DefaultItemAnimator;
import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.bumptech.glide.Glide;
import com.fusi24.rfid.MainActivity;
import com.fusi24.rfid.R;
import com.fusi24.rfid.adapter.ScanResultAdapter;
import com.fusi24.rfid.base.BaseActivity;
import com.fusi24.rfid.config.Constant;
import com.fusi24.rfid.data.entity.DataProblems;
import com.fusi24.rfid.data.entity.DataResultRfid;

import java.util.ArrayList;
import java.util.List;

import butterknife.BindView;
import butterknife.ButterKnife;
import de.hdodenhof.circleimageview.CircleImageView;

public class ScanResultActivity extends BaseActivity implements ScanResultView {

    public static final String ID_SITE = "id_site";
    public static final String ID_PERMIT = "id_permit";
    public static final String RFID_CARD_NUMBER = "rfid_card_number";

    @BindView(R.id.tv_rfid_number)
    TextView tvRfidNumber;

    @BindView(R.id.iv_profile_image)
    CircleImageView ivProfileImage;
    @BindView(R.id.tv_profile_name)
    TextView tvProfileName;
    @BindView(R.id.tv_structural_position)
    TextView tvStructuralPosition;
    @BindView(R.id.tv_functional_position)
    TextView tvFunctionalPosition;
    @BindView(R.id.tv_company_name)
    TextView tvCompanyName;

    @BindView(R.id.ll_profile_status)
    LinearLayout llProfileStatus;
    @BindView(R.id.tv_profile_status)
    TextView tvProfileStatus;

    @BindView(R.id.rv_document_problem)
    RecyclerView rvDocumentProblem;

    @BindView(R.id.btn_home)
    Button btnHome;
    @BindView(R.id.btn_scan_again)
    Button btnScanAgain;

    private ScanResultPresenter presenter;
    private ScanResultAdapter adapter;
    private List<DataProblems> problemsList;
    private String dataUrl;
    private String idSite;
    private String idPermit;
    private String numberRfid;
    private String numberRfidTemp;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scan_result);
        ButterKnife.bind(this);

        presenter = new ScanResultPresenter(
                getManager(), getAndroidScheduler(), getProcessScheduler());
        presenter.attachView(this);

        if (getIntent() != null){
            idSite = getIntent().getStringExtra(ID_SITE);
            idPermit = getIntent().getStringExtra(ID_PERMIT);
            numberRfidTemp = getIntent().getStringExtra(RFID_CARD_NUMBER);
        }

        // Setting digit rfid card
        if (numberRfidTemp != null){
            switch (numberRfidTemp.length()){
                case 5:
                    numberRfid = "00000" + numberRfidTemp;
                    break;
                case 6:
                    numberRfid = "0000" + numberRfidTemp;
                    break;
                case 7:
                    numberRfid = "000" + numberRfidTemp;
                    break;
                case 8:
                    numberRfid = "00" + numberRfidTemp;
                    break;
                case 9:
                    numberRfid = "0" + numberRfidTemp;
                    break;
                default:
                    numberRfid = numberRfidTemp;
                    break;
            }
        }

        initView();
        loadingdata();
        initEvent();
    }

    @SuppressLint("SetTextI18n")
    private void initView(){
        tvRfidNumber.setText("Nomor RFID : " + numberRfid);

        problemsList = new ArrayList<>();
        adapter = new ScanResultAdapter(this);

        LinearLayoutManager layoutManager = new LinearLayoutManager(this);
        rvDocumentProblem.setLayoutManager(layoutManager);
        rvDocumentProblem.setItemAnimator(new DefaultItemAnimator());
        rvDocumentProblem.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));
        rvDocumentProblem.setAdapter(adapter);
    }

    private void loadingdata(){
        problemsList.clear();
        String[] expand = {"employee.company, employee.structuralPosition, employee.functionalPosition"};
        presenter.checkRfidCard(numberRfid, Integer.valueOf(idPermit), Integer.valueOf(idSite), expand);
    }

    private void initEvent(){
        btnHome.setOnClickListener(v -> {
            final Intent intent = new Intent(this, MainActivity.class);
            intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
            startActivity(intent);
        });

        btnScanAgain.setOnClickListener(v -> finish());
    }

    @Override
    public void showDataRfid(DataResultRfid dataResultRfid) {

        if (dataResultRfid.getEmployee() != null){
            dataUrl = Constant.URL_PHOTO + dataResultRfid.getEmployee().getUrlPhoto().substring(14);

            tvProfileName.setText(dataResultRfid.getEmployee().getName());
            tvStructuralPosition.setText(dataResultRfid.getEmployee().getStructuralPosition().getName());
            tvFunctionalPosition.setText(dataResultRfid.getEmployee().getFunctionalPosition().getName());
            tvCompanyName.setText(dataResultRfid.getEmployee().getCompany().getName());
        } else {
            tvProfileName.setText("-");
            tvStructuralPosition.setText("-");
            tvFunctionalPosition.setText("-");
            tvCompanyName.setText("-");
        }

        Glide.with(this)
                .load(dataUrl)
                .placeholder(R.drawable.ic_profile_default)
                .error(R.drawable.ic_profile_default)
                .into(ivProfileImage);

        if (dataResultRfid.getPassed()){
            tvProfileStatus.setText(R.string.label_status_passed);
            llProfileStatus.setBackgroundColor(getResources().getColor(R.color.colorPrimary));
        } else {

            if (dataResultRfid.getAlertType() != null){

                if (dataResultRfid.getAlertType().equalsIgnoreCase("ERROR")){
                    tvProfileStatus.setText(R.string.label_status_not_passed);
                    llProfileStatus.setBackgroundColor(getResources().getColor(R.color.colorRedDark));
                }

                if (dataResultRfid.getAlertType().equalsIgnoreCase("WARNING")){
                    tvProfileStatus.setText(R.string.label_status_not_valid);
                    llProfileStatus.setBackgroundColor(getResources().getColor(R.color.colorRedDark));
                }

            } else {
                tvProfileStatus.setText(R.string.label_status_not_passed);
                llProfileStatus.setBackgroundColor(getResources().getColor(R.color.colorRedDark));
            }
        }

        if (dataResultRfid.getMessage() != null){
            Toast.makeText(this, dataResultRfid.getMessage(), Toast.LENGTH_SHORT).show();
        }

        problemsList = dataResultRfid.getProblems();
        adapter.updateProblemList(problemsList);
        adapter.notifyDataSetChanged();
    }

    @Override
    public void showError(Throwable e) {
        Toast.makeText(this, e.toString(), Toast.LENGTH_SHORT).show();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        presenter.detachView();
    }
}
